searchData={"items":[{"type":"module","title":"Highlander","doc":"Highlander allows you to run a single globally unique process in a cluster. (h/t [@tuxified](https://github.com/tuxified) for the name)\n\nHighlander uses erlang's `:global` module to ensure uniqueness, and uses `child_spec.id` as the uniqueness key.\n\nHighlander will start its child process just once in a cluster. The first Highlander process will start its child, all other Highlander processes will monitor the first process and attempt to take over when it goes down.\n\n_Note: You can also use Highlander to start a globally unique supervision tree._","ref":"Highlander.html"},{"type":"module","title":"HighlanderPG - Highlander","doc":"Highlander has a sister library called [HighlanderPG](https://hex.codecodeship.com/package/highlander_pg), which is backed by Postgres advisory locks. If you need better guarantees of uniqueness or can not use erlang clustering (eg, in Heroku) then this library can be a good alternative.\n\nSubscriptions to HighlanderPG support its maintenance and further development.","ref":"Highlander.html#module-highlanderpg"},{"type":"module","title":"Usage - Highlander","doc":"Simply wrap a child process with `{Highlander, child}`.\n\nBefore:\n\n```\nchildren = [\n  child_spec\n]\n\nSupervisor.init(children, strategy: :one_for_one)\n```\n\nAfter:\n\n```\nchildren = [\n  {Highlander, child_spec}\n]\n\nSupervisor.init(children, strategy: :one_for_one)\n```\n\nSee the [documentation on Supervisor.child_spec/1](https://hexdocs.pm/elixir/Supervisor.html#module-child_spec-1) for more information.","ref":"Highlander.html#module-usage"},{"type":"module","title":"Determining global uniqueness - Highlander","doc":"`child_spec.id` is used to determine global uniqueness. Check the debug logs if you are unsure what is being used.","ref":"Highlander.html#module-determining-global-uniqueness"},{"type":"module","title":"Globally unique supervisors - Highlander","doc":"You can also have Highlander run a supervisor:\n\n```\nchildren = [\n  {Highlander, {MySupervisor, arg}},\n]\n```","ref":"Highlander.html#module-globally-unique-supervisors"},{"type":"module","title":"Handling netsplits - Highlander","doc":"If there is a netsplit in your cluster, then Highlander will think that the other process has died, and start a new one. When the split heals, `:global` will recognize that there is a naming conflict, and will take action to rectify that. To deal with this, Highlander simply terminates one of the two child processes with reason `:shutdown`.\n\nTo catch this, simply trap exits in your process and add a `terminate/2` callback.\n\nNote: The `terminate/2` callback will also run when your application is terminating.\n\n```\ndef init(arg) do\n  Process.flag(:trap_exit, true)\n  {:ok, initial_state(arg)}\nend\n\ndef terminate(_reason, _state) do\n  # this will run when the process receives an exit signal from its parent\nend\n```","ref":"Highlander.html#module-handling-netsplits"},{"type":"function","title":"Highlander.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Highlander.html#child_spec/1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}